<?php
	
	/* Setup */
	function apollosegundo_setup(){

		/* Make theme available for translation */
		load_theme_textdomain( 'apollosegundo', get_template_directory() . '/languages' );

		/* Let WordPress manage the document title */
		add_theme_support('title-tag');

		/* Enable support for Post Thumbnails */
		add_theme_support( 'post-thumbnails' );

		/* Enable support for Post Formats */
		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'quote',
			'link'
		) );

		/* Register locations of menus */
		register_nav_menus( array(
			'primary' => esc_html__( 'Principal', 'apollosegundo' ),
			'secondary' => esc_html__( 'Pie de página', 'apollosegundo' )
		) );

		add_theme_support( 'automatic-feed-links' );
	}
	add_action( 'after_setup_theme', 'apollosegundo_setup' );

	/* Register widget area */
	function apollosegundo_widgets_init(){
		register_sidebar( array(
			'name' => esc_html__( 'Barra lateral', 'apollosegundo' ),
			'id' => 'sidebar-1',
			'description' => esc_html__( 'Elige los widgets que deseas mostrar', 'apollosegundo' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget' => '</section>'
		)	);
	}
	add_action( 'widgets_init', 'apollosegundo_widgets_init' );

	/* Add styles */
	function apollosegundo_enqueue_style(){
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css' );
		wp_enqueue_style( 'normalize', get_template_directory_uri() . '/assets/css/normalize.css' );
		wp_enqueue_style( 'apollosegundo-style', get_stylesheet_uri(), array('normalize'), 1.0, 'all');
	}
	add_action( 'wp_enqueue_scripts', 'apollosegundo_enqueue_style' );

	/* Add scripts */
	function apollosegundo_enqueue_script() {
		wp_enqueue_script( 'apollosegundo-scripts', get_template_directory_uri() . '/assets/js/functions.js', array('jquery'), 1.0, true );
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'apollosegundo_enqueue_script' );

	/* Customized comments */
	/* https://developer.wordpress.org/reference/functions/wp_list_comments/ */
	function apollosegundo_comment($comment, $args, $depth){
		$GLOBALS['comment'] = $comment;
		global $post;
	?>
		<li>
		<article class="comment">
			<div class="comment-author">
				<?php
				echo get_avatar( get_comment_author_email(), 50, '', get_comment_author() );
				?>
				<span class="author-name">
					<?php comment_author_link(); ?>
				</span>
			</div><!-- .comment-author -->
			<div class="comment-content">
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em><?php _e( 'Tu comentario está pendiente de moderación.', 'apollosegundo' ) ?></em>
					<br/>
				<?php endif; ?>
				<?php comment_text(); ?>
			</div><!-- .comment-content -->
			<div class="comment-footer">
				<span class="comment-date"><?php comment_date(); ?></span>
				<?php comment_reply_link( array_merge( $args, array(
					'reply_text' => __( 'Responder', 'apollosegundo' ),
					'depth'      => $depth,
					'max_depth'  => $args['max_depth']
				) ) ); ?>
				<?php edit_comment_link( __( 'Editar', 'apollosegundo' ) ); ?>
			</div><!-- .comment-footer -->
		</article><!-- .comment -->
	<?php
	}

	/**
	 * Customizer additions.
 	*/
	require get_template_directory() . '/inc/external.php';

	/**
	 * Customizer additions.
 	*/
	require get_template_directory() . '/inc/customizer.php';
?>